@@ -69,17 +69,13 @@ void		set_menu_applet_orient	(Menu *menu,
 void		setup_menuitem		(GtkWidget *menuitem,
 					 GtkWidget *pixmap,
 					 const char *title);
-void		make_panel_submenu	(GtkWidget *menu,
-					 gboolean fake_submenus,
-					 gboolean is_basep);
 
-GtkWidget *	create_panel_root_menu	(PanelWidget *panel);
-GtkWidget *     create_panel_context_menu (PanelWidget *panel);
+GtkWidget      *create_panel_context_menu (PanelWidget *panel);
+GtkWidget      *create_panel_root_menu    (PanelWidget *panel);
 
 void		menu_properties		(Menu *menu);
 
-void		panel_lock		(GtkWidget *widget,
-					 gpointer data);
+void		panel_lock		(GtkWidget *widget);
 
 /*to be called on startup to load in some of the directories*/
 void		init_menus		(void);
@@ -101,11 +97,12 @@ gboolean	menu_need_reread	(GtkWidget *menuw);
 
 void		setup_internal_applet_drag (GtkWidget *menuitem,
 					    const char *applet_type);
-GtkWidget *	create_root_menu	(GtkWidget *root_menu,
-					 gboolean fake_submenus,
-					 int flags,
-					 gboolean is_basep,
-					 gboolean run_item);
+GtkWidget *	create_root_menu	(GtkWidget   *root_menu,
+					 PanelWidget *panel,
+					 gboolean     fake_submenus,
+					 int          flags,
+					 gboolean     is_basep,
+					 gboolean     extra_items);
 
 /* some gtk code cut-n-paste action */
 void		our_gtk_menu_position	(GtkMenu *menu);
@@ -124,9 +121,6 @@ enum {
 	HIDEBUTTONS_NONE
 };
 
-#define PANEL_MENU_HAVE_ICONS_KEY "/desktop/gnome/menus/show-icons"
-gboolean panel_menu_have_icons   (void);
-
 GtkWidget *	panel_menu_new		(void);
 void		panel_load_menu_image_deferred (GtkWidget *image_menu_item,
 						const char *image_filename,
